@@ -17,7 +17,7 @@ rm $JS_DIR/jquery-ui.js
 rm $JS_DIR/modernizr.custom.js
 rm $JS_DIR/raphael-min.js
 rm $JS_DIR/tools.tooltip.js
-rm $DIR/spec/public/highlight/highlight.pack.js
+rm $DIR/spec/public/scripts/highlight.pack.js
 
 wget http://code.jquery.com/jquery-1.8.2.js                                        -O $JS_DIR/jquery.js
 wget http://ajax.googleapis.com/ajax/libs/jqueryui/1.9.0/jquery-ui.js              -O $JS_DIR/jquery-ui.js
